==> 0.0.6.tar.gz: lib/src/responsive_row.dart <==
import 'package:flutter/cupertino.dart';
import 'responsive_widget.dart';

/// Responsive row which occupies all line by default and contains 12 columns, used by [ResponsiveCol] as layout reference.
class ResponsiveRow extends ResponsiveWidget {
  /// number of columns on each line
  final int columns = 12;

  ResponsiveRow({
    Key key,
    Color backgroundColor,
    List<Widget> children,
    Alignment alignment,
    BoxDecoration decoration,
    EdgeInsets padding,
    EdgeInsets margin,
    double width,
    double maxWidth,
    double minWidth,
    double height,
    double maxHeight,
    double minHeight,
  }) : super(
            key: key,
            alignment: alignment,
            backgroundColor: backgroundColor,
            decoration: decoration,
            padding: padding,
            margin: margin,
            width: width,
            maxWidth: maxWidth,
            minWidth: minWidth,
            height: height,
            maxHeight: maxHeight,
            minHeight: minHeight,
            children: children);

  @override
  buildWidget(BuildContext context) {
    // Just rebuild objects if its necessary
    return LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
      return Container(
          alignment: alignment ?? Alignment.topLeft,
          width: (width != null && width < 0)
              ? null
              : getWidgetWidth(constraints.maxWidth),
          height: getWidgetHeight(constraints.maxHeight),
          decoration: decoration,
          padding: padding,
          margin: margin,
          color: backgroundColor,
          child: children != null ? Wrap(children: children) : null);
    });
  }
}

==> 1.1.0.tar.gz: lib/src/responsive_row.dart <==
import 'package:flutter/cupertino.dart';
import 'responsive_widget.dart';

/// Responsive row which occupies all line by default and contains 12 columns, used by [ResponsiveCol] as layout reference.
class ResponsiveRow extends ResponsiveWidget {
  /// number of columns on each line
  final int columns = 12;

  const ResponsiveRow({
    Key? key,
    Color? backgroundColor,
    List<Widget>? children,
    Alignment? alignment,
    BoxDecoration? decoration,
    EdgeInsets? padding,
    EdgeInsets? margin,
    double? width,
    double? maxWidth,
    double? minWidth,
    double? height,
    double? maxHeight,
    double? minHeight,
  }) : super(
            key: key,
            alignment: alignment,
            backgroundColor: backgroundColor,
            decoration: decoration,
            padding: padding,
            margin: margin,
            width: width,
            maxWidth: maxWidth,
            minWidth: minWidth,
            height: height,
            maxHeight: maxHeight,
            minHeight: minHeight,
            children: children);

  @override
  buildWidget(BuildContext context) {
    // Just rebuild objects if its necessary
    return LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
      return Container(
          alignment: alignment ?? Alignment.topLeft,
          width: (width ?? 0) < 0 ? null : getWidgetWidth(constraints.maxWidth),
          height: getWidgetHeight(constraints.maxHeight),
          decoration: decoration,
          padding: padding,
          margin: margin,
          color: backgroundColor,
          child: children != null ? Wrap(children: children!) : null);
    });
  }
}
